@@ -3,5 +3,5 @@
 package cli
 
 const (
-	TERMINAL_CLEAR_LINE = "\r\x1b[2K"
+	TerminalClearLine = "\r\x1b[2K"
 )
