@@ -2,7 +2,9 @@ package cli
 
 import (
 	"context"
+	"errors"
 	"fmt"
+	"math"
 	"os"
 	"strings"
 	"sync"
@@ -11,8 +13,10 @@ import (
 	"github.com/OJ/gobuster/v3/libgobuster"
 )
 
-const ruler = "==============================================================="
-const cliProgressUpdate = 500 * time.Millisecond
+const (
+	ruler             = "==============================================================="
+	cliProgressUpdate = 500 * time.Millisecond
+)
 
 // resultWorker outputs the results as they come in. This needs to be a range and should not handle
 // the context so the channel always has a receiver and libgobuster will not block.
@@ -36,7 +40,12 @@ func resultWorker(g *libgobuster.Gobuster, filename string, wg *sync.WaitGroup)
 		}
 		if s != "" {
 			s = strings.TrimSpace(s)
-			_, _ = fmt.Printf("%s%s\n", TERMINAL_CLEAR_LINE, s)
+			if g.Opts.NoProgress || g.Opts.Quiet {
+				_, _ = fmt.Printf("%s\n", s) // nolint forbidigo
+			} else {
+				// only print the clear line when progress output is enabled
+				_, _ = fmt.Printf("%s%s\n", TerminalClearLine, s) // nolint forbidigo
+			}
 			if f != nil {
 				err = writeToFile(f, s)
 				if err != nil {
@@ -72,6 +81,8 @@ func messageWorker(g *libgobuster.Gobuster, wg *sync.WaitGroup) {
 				g.Logger.Debug(msg.Message)
 			case libgobuster.LevelError:
 				g.Logger.Error(msg.Message)
+			case libgobuster.LevelWarn:
+				g.Logger.Warn(msg.Message)
 			case libgobuster.LevelInfo:
 				g.Logger.Info(msg.Message)
 			default:
@@ -82,18 +93,17 @@ func messageWorker(g *libgobuster.Gobuster, wg *sync.WaitGroup) {
 }
 
 func printProgress(g *libgobuster.Gobuster) {
-	if !g.Opts.Quiet && !g.Opts.NoProgress {
-		requestsIssued := g.Progress.RequestsIssued()
-		requestsExpected := g.Progress.RequestsExpected()
-		if g.Opts.Wordlist == "-" {
-			s := fmt.Sprintf("%sProgress: %d", TERMINAL_CLEAR_LINE, requestsIssued)
-			_, _ = fmt.Fprint(os.Stderr, s)
-			// only print status if we already read in the wordlist
-		} else if requestsExpected > 0 {
-			s := fmt.Sprintf("%sProgress: %d / %d (%3.2f%%)", TERMINAL_CLEAR_LINE, requestsIssued, requestsExpected, float32(requestsIssued)*100.0/float32(requestsExpected))
-			_, _ = fmt.Fprint(os.Stderr, s)
-		}
+	requestsIssued := g.Progress.RequestsIssued()
+	requestsExpected := g.Progress.RequestsExpected()
+	if requestsExpected == 0 {
+		requestsExpected = 1 // avoid division by zero
 	}
+	percent := float32(requestsIssued) * 100.0 / float32(requestsExpected)
+	if math.IsNaN(float64(percent)) {
+		percent = 0.0
+	}
+	s := fmt.Sprintf("%sProgress: %d / %d (%3.2f%%)", TerminalClearLine, requestsIssued, requestsExpected, percent)
+	_, _ = fmt.Fprint(os.Stderr, s)
 }
 
 // progressWorker outputs the progress every tick. It will stop once cancel() is called
@@ -110,14 +120,14 @@ func progressWorker(ctx context.Context, g *libgobuster.Gobuster, wg *sync.WaitG
 		case <-ctx.Done():
 			// print the final progress so we end at 100%
 			printProgress(g)
-			fmt.Println()
+			fmt.Println() // nolint:forbidigo
 			return
 		}
 	}
 }
 
 func writeToFile(f *os.File, output string) error {
-	_, err := f.WriteString(fmt.Sprintf("%s\n", output))
+	_, err := fmt.Fprintf(f, "%s\n", output)
 	if err != nil {
 		return fmt.Errorf("[!] Unable to write to file %w", err)
 	}
@@ -125,14 +135,14 @@ func writeToFile(f *os.File, output string) error {
 }
 
 // Gobuster is the main entry point for the CLI
-func Gobuster(ctx context.Context, opts *libgobuster.Options, plugin libgobuster.GobusterPlugin, log libgobuster.Logger) error {
+func Gobuster(ctx context.Context, opts *libgobuster.Options, plugin libgobuster.GobusterPlugin, log *libgobuster.Logger) error {
 	// Sanity checks
 	if opts == nil {
-		return fmt.Errorf("please provide valid options")
+		return errors.New("please provide valid options")
 	}
 
 	if plugin == nil {
-		return fmt.Errorf("please provide a valid plugin")
+		return errors.New("please provide a valid plugin")
 	}
 
 	ctxCancel, cancel := context.WithCancel(ctx)
@@ -161,6 +171,15 @@ func Gobuster(ctx context.Context, opts *libgobuster.Options, plugin libgobuster
 		log.Println(ruler)
 	}
 
+	fi, err := os.Stdout.Stat()
+	if err != nil {
+		return err
+	}
+	// check if we are not in a terminal. If so, disable output
+	if (fi.Mode() & os.ModeCharDevice) != os.ModeCharDevice {
+		opts.NoProgress = true
+	}
+
 	// our waitgroup for all goroutines
 	// this ensures all goroutines are finished
 	// when we call wg.Wait()
