@@ -21,10 +21,11 @@ type OptionsDir struct {
 	DiscoverBackup             bool
 	ExcludeLength              string
 	ExcludeLengthParsed        libgobuster.Set[int]
+	Force                      bool
 }
 
-// NewOptionsDir returns a new initialized OptionsDir
-func NewOptionsDir() *OptionsDir {
+// NewOptions returns a new initialized OptionsDir
+func NewOptions() *OptionsDir {
 	return &OptionsDir{
 		StatusCodesParsed:          libgobuster.NewSet[int](),
 		StatusCodesBlacklistParsed: libgobuster.NewSet[int](),
