@@ -8,9 +8,10 @@ import (
 type OptionsGCS struct {
 	libgobuster.BasicHTTPOptions
 	MaxFilesToList int
+	ShowFiles      bool
 }
 
-// NewOptionsGCS returns a new initialized OptionsS3
-func NewOptionsGCS() *OptionsGCS {
+// NewOptions returns a new initialized OptionsS3
+func NewOptions() *OptionsGCS {
 	return &OptionsGCS{}
 }
