@@ -6,8 +6,10 @@ import "context"
 type GobusterPlugin interface {
 	Name() string
 	PreRun(context.Context, *Progress) error
-	ProcessWord(context.Context, string, *Progress) error
+	ProcessWord(context.Context, string, *Progress) (Result, error)
 	AdditionalWords(string) []string
+	AdditionalWordsLen() int
+	AdditionalSuccessWords(string) []string
 	GetConfigString() (string, error)
 }
 
