@@ -1,7 +1,7 @@
 package libgobuster
 
 import (
-	"log"
+	"log" // nolint:depguard
 	"os"
 
 	"github.com/fatih/color"
@@ -11,15 +11,17 @@ type Logger struct {
 	log      *log.Logger
 	errorLog *log.Logger
 	debugLog *log.Logger
+	warnLog  *log.Logger
 	infoLog  *log.Logger
 	debug    bool
 }
 
-func NewLogger(debug bool) Logger {
-	return Logger{
+func NewLogger(debug bool) *Logger {
+	return &Logger{
 		log:      log.New(os.Stdout, "", 0),
 		errorLog: log.New(os.Stderr, color.New(color.FgRed).Sprint("[ERROR] "), 0),
 		debugLog: log.New(os.Stderr, color.New(color.FgBlue).Sprint("[DEBUG] "), 0),
+		warnLog:  log.New(os.Stderr, color.New(color.FgYellow).Sprint("[WARN] "), 0),
 		infoLog:  log.New(os.Stderr, color.New(color.FgCyan).Sprint("[INFO] "), 0),
 		debug:    debug,
 	}
@@ -39,6 +41,14 @@ func (l Logger) Debugf(format string, v ...any) {
 	l.debugLog.Printf(format, v...)
 }
 
+func (l Logger) Warn(v ...any) {
+	l.warnLog.Print(v...)
+}
+
+func (l Logger) Warnf(format string, v ...any) {
+	l.warnLog.Printf(format, v...)
+}
+
 func (l Logger) Info(v ...any) {
 	l.infoLog.Print(v...)
 }
